@@ -1,22 +1,23 @@
+import sys
+
 from cleo import Application
 
-from rgov.commands import check, search, reindex, daemon
+from rgov.commands import check, search, initialize, check_daemon, run
 
 commands = [
     check.CheckCommand(),
     search.SearchCommand(),
-    reindex.UpdateIndexCommand(),
-    daemon.DaemonCommand(),
+    initialize.InitCommand(),
+    run.RunCommand(),
+    check_daemon.DaemonCommand(),
 ]
 
 application = Application()
 
 [application.add(command) for command in commands]
 
-
-def main() -> int:
-    return application.run()
-
+def main():
+    application.run()
 
 if __name__ == "__main__":
-    run()
+    main()
